# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`dovecot`](#dovecot): This class allows simple configuration of the dovecot server.

#### Private Classes

* `dovecot::configuration`: This class handles dovecot configuration.
* `dovecot::install`: This class handles packages.
* `dovecot::poolmon`: Installs and configures Poolmon.
* `dovecot::service`: This class handles services.

### Defined types

* [`dovecot::config`](#dovecot--config): This type manages a single config entry.
* [`dovecot::configentry`](#dovecot--configentry): Manages a single dovecot config entry.
* [`dovecot::configfile`](#dovecot--configfile): Manages a single dovecot config file
* [`dovecot::extconfigfile`](#dovecot--extconfigfile): Resource for external config files providing a very basic key-value interface.
* [`dovecot::file`](#dovecot--file): Simple file resource that notifies the dovecot service.
* [`dovecot::sieve`](#dovecot--sieve): Simple sieve script resource that gets compiled by sievec and

### Functions

* [`dovecot::create_config_file_resources`](#dovecot--create_config_file_resources): create {dovecot::config} resources from a nested hash (e.g. from hiera)
* [`dovecot::create_config_resources`](#dovecot--create_config_resources): create dovecot::config resources from a nested hash (e.g. from hiera)
* [`dovecot::create_extconfigfile_resources`](#dovecot--create_extconfigfile_resources): create {dovecot::extconfigfile} resources from a nested hash (e.g. from hiera)
* [`dovecot::print_config_value`](#dovecot--print_config_value): returns a properly quoted dovecot config value

## Classes

### <a name="dovecot"></a>`dovecot`

There is no semantic abstraction done in this class, all config
parameters are passed directly to dovecot via config files.

#### Examples

##### Using a profile to load merged values from hiera:

```puppet
$config = hiera_hash("${title}::config", {})
$configs = hiera_hash("${title}::configs", {})
$plugins = hiera_array("${title}::plugins", undef)
class { 'dovecot':
  plugins => $plugins,
  config => $config,
  configs => $configs,
}
```

#### Parameters

The following parameters are available in the `dovecot` class:

* [`config`](#-dovecot--config)
* [`config_path`](#-dovecot--config_path)
* [`configs`](#-dovecot--configs)
* [`configs_mode`](#-dovecot--configs_mode)
* [`directory_private_manage`](#-dovecot--directory_private_manage)
* [`extconfigs`](#-dovecot--extconfigs)
* [`extconfigs_mode`](#-dovecot--extconfigs_mode)
* [`package_ensure`](#-dovecot--package_ensure)
* [`package_manage`](#-dovecot--package_manage)
* [`package_name`](#-dovecot--package_name)
* [`plugin`](#-dovecot--plugin)
* [`plugins`](#-dovecot--plugins)
* [`poolmon_archive_params`](#-dovecot--poolmon_archive_params)
* [`poolmon_basepath`](#-dovecot--poolmon_basepath)
* [`poolmon_config`](#-dovecot--poolmon_config)
* [`poolmon_config_file`](#-dovecot--poolmon_config_file)
* [`poolmon_exec`](#-dovecot--poolmon_exec)
* [`poolmon_manage`](#-dovecot--poolmon_manage)
* [`poolmon_service_enable`](#-dovecot--poolmon_service_enable)
* [`poolmon_service_ensure`](#-dovecot--poolmon_service_ensure)
* [`poolmon_service_file`](#-dovecot--poolmon_service_file)
* [`poolmon_service_mode`](#-dovecot--poolmon_service_mode)
* [`poolmon_service_provider`](#-dovecot--poolmon_service_provider)
* [`poolmon_version`](#-dovecot--poolmon_version)
* [`purge_unmanaged`](#-dovecot--purge_unmanaged)
* [`service_enable`](#-dovecot--service_enable)
* [`service_ensure`](#-dovecot--service_ensure)
* [`service_manage`](#-dovecot--service_manage)
* [`service_name`](#-dovecot--service_name)
* [`sievec`](#-dovecot--sievec)

##### <a name="-dovecot--config"></a>`config`

Data type: `Hash`

A hash of config file entries, with nested hashes parsed as sections.

##### <a name="-dovecot--config_path"></a>`config_path`

Data type: `String`

The path to the dovecot config dir.

##### <a name="-dovecot--configs"></a>`configs`

Data type: `Hash`

A hash of conf.d file names to $config-style hashes.

##### <a name="-dovecot--configs_mode"></a>`configs_mode`

Data type: `String`

The file permissions that should be applied.

##### <a name="-dovecot--directory_private_manage"></a>`directory_private_manage`

Data type: `Boolean`

Whether to manage the private directory.

##### <a name="-dovecot--extconfigs"></a>`extconfigs`

Data type: `Hash`

A hash of external config files.

##### <a name="-dovecot--extconfigs_mode"></a>`extconfigs_mode`

Data type: `String`

The file permissions that should be applied.

##### <a name="-dovecot--package_ensure"></a>`package_ensure`

Data type: `String`

Whether to install the dovecot package, and what version to install.
Values: 'present', 'latest', or a specific version number. Default value: 'present'.

##### <a name="-dovecot--package_manage"></a>`package_manage`

Data type: `Boolean`

Whether to install the dovecot core and plugin packages.

##### <a name="-dovecot--package_name"></a>`package_name`

Data type: `Array[String]`

The name of the main dovecot package.

##### <a name="-dovecot--plugin"></a>`plugin`

Data type: `Hash`

Contains a package_name parameter for each plugin (if available).

##### <a name="-dovecot--plugins"></a>`plugins`

Data type: `Array[String[1]]`

The list of plugins to install.

##### <a name="-dovecot--poolmon_archive_params"></a>`poolmon_archive_params`

Data type: `Hash`

Additional parameters that should be passed through to the `archive` resource.

##### <a name="-dovecot--poolmon_basepath"></a>`poolmon_basepath`

Data type: `String`

The base path for installing poolmon.

##### <a name="-dovecot--poolmon_config"></a>`poolmon_config`

Data type: `Hash`

A list of config options.

##### <a name="-dovecot--poolmon_config_file"></a>`poolmon_config_file`

Data type: `String`

The path and filename of the configuration file.

##### <a name="-dovecot--poolmon_exec"></a>`poolmon_exec`

Data type: `String`

The path to the poolmon binary.

##### <a name="-dovecot--poolmon_manage"></a>`poolmon_manage`

Data type: `Boolean`

Whether to manage the poolmon service. Default value: false.

##### <a name="-dovecot--poolmon_service_enable"></a>`poolmon_service_enable`

Data type: `Boolean`

Whether the poolmon service should be configured for automatic startup.

##### <a name="-dovecot--poolmon_service_ensure"></a>`poolmon_service_ensure`

Data type: `Enum['running', 'stopped']`

The desired state for the service.

##### <a name="-dovecot--poolmon_service_file"></a>`poolmon_service_file`

Data type: `String`

The path to the service file.

##### <a name="-dovecot--poolmon_service_mode"></a>`poolmon_service_mode`

Data type: `String`

File permissions for the service file.

##### <a name="-dovecot--poolmon_service_provider"></a>`poolmon_service_provider`

Data type: `Enum['init', 'rc', 'systemd']`

The provider used to handle services, e.g. systemd.

##### <a name="-dovecot--poolmon_version"></a>`poolmon_version`

Data type: `String`

The version of poolmon that should be installed.

##### <a name="-dovecot--purge_unmanaged"></a>`purge_unmanaged`

Data type: `Boolean`

Whether to purge all unmanaged files in the dovecot directory.

##### <a name="-dovecot--service_enable"></a>`service_enable`

Data type: `Boolean`

Whether to enable the dovecot service at boot. Default value: true.

##### <a name="-dovecot--service_ensure"></a>`service_ensure`

Data type: `Enum['running', 'stopped']`

Whether the dovecot service should be running. Default value: 'running'.

##### <a name="-dovecot--service_manage"></a>`service_manage`

Data type: `Boolean`

Whether to manage the dovecot service.

##### <a name="-dovecot--service_name"></a>`service_name`

Data type: `String`

The dovecot service to manage. Default value: varies by operating system.

##### <a name="-dovecot--sievec"></a>`sievec`

Data type: `Stdlib::Absolutepath`

The path to the sievec binary.

## Defined types

### <a name="dovecot--config"></a>`dovecot::config`

Dovecot uses its own config format. This format basically allows to define a
hierarchy of configuration sections (and syntactically identical filters, so
they will just be treated as sections by this module).

Since in puppet, we want to map each single config entry as its own resource,
the hierarchy has been "flattened" to hierarchical keys.

A key/value pair `foo = bar` nested in a `section` object, would look like
this in a dovecot config file:

```json
section {
  foo = bar
}
```

To reference this key in a dovecot::config variable, you would use the
notation `section.foo`.

Title/Name format
------------

This module can manage both a global dovecot.conf and single conf.d files. The
module author recommends single file setups for puppet-managed hosts, but users
can choose to split their managed config into single files.

To specify which file a config entry should got to, you can use the `file`
parameter.

For convenience reasons, however, this resource also allows to encode the values
for $sections, $key, and $file into the resource's name (which is usally the same as
its title).

If the $name of the resource matches the format "[<file>:][<sections>.]<name>", and
all of $file, $sections, and $key have not been specified, the values from the name
are used.
This simplifies creating unique resources for identical settings in different
files.

#### Parameters

The following parameters are available in the `dovecot::config` defined type:

* [`sections`](#-dovecot--config--sections)
* [`key`](#-dovecot--config--key)
* [`file`](#-dovecot--config--file)
* [`value`](#-dovecot--config--value)
* [`comment`](#-dovecot--config--comment)
* [`ensure`](#-dovecot--config--ensure)

##### <a name="-dovecot--config--sections"></a>`sections`

Data type: `Optional[Array[String]]`

An array of section names that define the hierarchical name of this key.
E.g. `["protocol imap", "plugin"] to denote the `protocol imap { plugin {` section.

Default value: `undef`

##### <a name="-dovecot--config--key"></a>`key`

Data type: `Optional[String]`

The key name of the config setting. The key is expected as a single non-hierachical
name without any sections/filters.
The special values `!include` and `!include_try` can be used for includes.

Default value: `undef`

##### <a name="-dovecot--config--file"></a>`file`

Data type: `Optional[String]`

The file to put the value in. If undef (the default), the value is put into the
global dovecot.conf, otherwise the value si written to conf.d/${file}.conf
The value of this parameter must not include any path information or file extension.
E.g. `10-auth`

Default value: `undef`

##### <a name="-dovecot--config--value"></a>`value`

Data type: `Variant[Boolean, Integer, String]`

the value of this config entry.

##### <a name="-dovecot--config--comment"></a>`comment`

Data type: `Optional[String]`

an optional comment that will be written to the config file above the entry

Default value: `undef`

##### <a name="-dovecot--config--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

whether this entry should be `present` or `absent`. Usually not needed at all,
because the config file will be fully managed by puppet and re-created each time.

Default value: `'present'`

### <a name="dovecot--configentry"></a>`dovecot::configentry`

Manages a single dovecot config entry.

* **Note** This class is only for internal use, use dovecot::config instead.

* **See also**
  * dovecot::config

#### Parameters

The following parameters are available in the `dovecot::configentry` defined type:

* [`comment`](#-dovecot--configentry--comment)
* [`ensure`](#-dovecot--configentry--ensure)
* [`file`](#-dovecot--configentry--file)
* [`key`](#-dovecot--configentry--key)
* [`sections`](#-dovecot--configentry--sections)
* [`value`](#-dovecot--configentry--value)

##### <a name="-dovecot--configentry--comment"></a>`comment`

Data type: `Optional[String]`

an optional comment to be printed above the entry

Default value: `undef`

##### <a name="-dovecot--configentry--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Whether the entry should be `present` or `absent`.

Default value: `'present'`

##### <a name="-dovecot--configentry--file"></a>`file`

Data type: `Stdlib::Absolutepath`

The file to put the entry in.

##### <a name="-dovecot--configentry--key"></a>`key`

Data type: `String`

The entry's key, or !include/!include_try.

##### <a name="-dovecot--configentry--sections"></a>`sections`

Data type: `Array[String]`

The entry's sections as an array.

Default value: `[]`

##### <a name="-dovecot--configentry--value"></a>`value`

Data type: `Variant[Boolean, Integer, String]`

The entry's value.

### <a name="dovecot--configfile"></a>`dovecot::configfile`

Manages a single dovecot config file

* **Note** This define is only for internal use, use dovecot::config instead.

* **See also**
  * dovecot::config

#### Parameters

The following parameters are available in the `dovecot::configfile` defined type:

* [`comment`](#-dovecot--configfile--comment)
* [`ensure`](#-dovecot--configfile--ensure)
* [`file`](#-dovecot--configfile--file)
* [`group`](#-dovecot--configfile--group)
* [`mode`](#-dovecot--configfile--mode)
* [`owner`](#-dovecot--configfile--owner)

##### <a name="-dovecot--configfile--comment"></a>`comment`

Data type: `Optional[String]`

An optional comment to be printed at the top of the file instead of
the default warning.

Default value: `undef`

##### <a name="-dovecot--configfile--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Whether the file should be `present` or `absent`.

Default value: `'present'`

##### <a name="-dovecot--configfile--file"></a>`file`

Data type: `Stdlib::Absolutepath`

The file to put the entry in.

Default value: `$title`

##### <a name="-dovecot--configfile--group"></a>`group`

Data type: `Variant[Integer, String]`

The group that should own the file.

Default value: `0`

##### <a name="-dovecot--configfile--mode"></a>`mode`

Data type: `Variant[Integer, String]`

The permissions for the file.

Default value: `$dovecot::configs_mode`

##### <a name="-dovecot--configfile--owner"></a>`owner`

Data type: `Variant[Integer, String]`

The user that should own the file.

Default value: `'root'`

### <a name="dovecot--extconfigfile"></a>`dovecot::extconfigfile`

Resource for external config files providing a very basic key-value interface.

#### Parameters

The following parameters are available in the `dovecot::extconfigfile` defined type:

* [`additional_content`](#-dovecot--extconfigfile--additional_content)
* [`entries`](#-dovecot--extconfigfile--entries)
* [`group`](#-dovecot--extconfigfile--group)
* [`mode`](#-dovecot--extconfigfile--mode)
* [`owner`](#-dovecot--extconfigfile--owner)
* [`relpath`](#-dovecot--extconfigfile--relpath)
* [`warn`](#-dovecot--extconfigfile--warn)

##### <a name="-dovecot--extconfigfile--additional_content"></a>`additional_content`

Data type: `Optional[String]`

Additional content for the file.

Default value: `undef`

##### <a name="-dovecot--extconfigfile--entries"></a>`entries`

Data type: `Hash[String, String]`

A hash of string=string entries. All values will be
written as-is to the file, any escaping must already
be applied.

##### <a name="-dovecot--extconfigfile--group"></a>`group`

Data type: `Variant[Integer, String]`

The group that should own the file.

Default value: `0`

##### <a name="-dovecot--extconfigfile--mode"></a>`mode`

Data type: `Variant[Integer, String]`

The permissions for the file.

Default value: `$dovecot::extconfigs_mode`

##### <a name="-dovecot--extconfigfile--owner"></a>`owner`

Data type: `Variant[Integer, String]`

The user that should own the file.

Default value: `'root'`

##### <a name="-dovecot--extconfigfile--relpath"></a>`relpath`

Data type: `String`

The path of the external config file relative to
dovecot::config_path, including the desired extension.
Defaults to the resource title.

Default value: `$title`

##### <a name="-dovecot--extconfigfile--warn"></a>`warn`

Data type: `Variant[Boolean, String]`

Whether to prepend the default warning (if `true`), a
custom warning (if a `String`), or nothing at all.

Default value: `true`

### <a name="dovecot--file"></a>`dovecot::file`

Simple file resource that notifies the dovecot service.

#### Parameters

The following parameters are available in the `dovecot::file` defined type:

* [`content`](#-dovecot--file--content)
* [`group`](#-dovecot--file--group)
* [`mode`](#-dovecot--file--mode)
* [`owner`](#-dovecot--file--owner)
* [`path`](#-dovecot--file--path)

##### <a name="-dovecot--file--content"></a>`content`

Data type: `String`

The content of the file.

##### <a name="-dovecot--file--group"></a>`group`

Data type: `Variant[Integer, String]`

The group that should own the file.

Default value: `0`

##### <a name="-dovecot--file--mode"></a>`mode`

Data type: `Variant[Integer, String]`

The permissions for the file.

Default value: `'0644'`

##### <a name="-dovecot--file--owner"></a>`owner`

Data type: `Variant[Integer, String]`

The user that should own the file.

Default value: `'root'`

##### <a name="-dovecot--file--path"></a>`path`

Data type: `Stdlib::Absolutepath`

The target path for the file.

### <a name="dovecot--sieve"></a>`dovecot::sieve`

notifies the dovecot service.

#### Parameters

The following parameters are available in the `dovecot::sieve` defined type:

* [`content`](#-dovecot--sieve--content)
* [`group`](#-dovecot--sieve--group)
* [`mode`](#-dovecot--sieve--mode)
* [`owner`](#-dovecot--sieve--owner)
* [`path`](#-dovecot--sieve--path)
* [`sievec`](#-dovecot--sieve--sievec)
* [`source`](#-dovecot--sieve--source)

##### <a name="-dovecot--sieve--content"></a>`content`

Data type: `String`

The content of the file.

Default value: `undef`

##### <a name="-dovecot--sieve--group"></a>`group`

Data type: `Variant[Integer, String]`

The group that should own the file.

Default value: `0`

##### <a name="-dovecot--sieve--mode"></a>`mode`

Data type: `Variant[Integer, String]`

The permissions for the file.

Default value: `'0644'`

##### <a name="-dovecot--sieve--owner"></a>`owner`

Data type: `Variant[Integer, String]`

The user that should own the file.

Default value: `'root'`

##### <a name="-dovecot--sieve--path"></a>`path`

Data type: `Stdlib::Absolutepath`

The target path for the file.

Default value: `$name`

##### <a name="-dovecot--sieve--sievec"></a>`sievec`

Data type: `Stdlib::Absolutepath`

The path to the sievec binary.

Default value: `$dovecot::sievec`

##### <a name="-dovecot--sieve--source"></a>`source`

Data type: `Optional[String]`

Optional source for the file resource to use instead of `$content`.

Default value: `undef`

## Functions

### <a name="dovecot--create_config_file_resources"></a>`dovecot::create_config_file_resources`

Type: Puppet Language

Function: dovecot::create_config_file_resources()
=============

Create {dovecot::config} resources from a nested hash, suitable for
conveniently loading values from hiera.

The first level of keys is the config files to be written to, the
values being the hierarchical values that will be passed to
the {dovecot::create_config_resources} function

#### `dovecot::create_config_file_resources(Hash[String, Hash] $configfile_hash, Boolean $include_in_main_config = true, Hash $params = {})`

Function: dovecot::create_config_file_resources()
=============

Create {dovecot::config} resources from a nested hash, suitable for
conveniently loading values from hiera.

The first level of keys is the config files to be written to, the
values being the hierarchical values that will be passed to
the {dovecot::create_config_resources} function

Returns: `Any`

##### `configfile_hash`

Data type: `Hash[String, Hash]`

a hash of config file names mapped to config hashes

##### `include_in_main_config`

Data type: `Boolean`

whether the single config files should be included from dovecot.conf

##### `params`

Data type: `Hash`

a hash of params passed to the {dovecot::config} resource (:file will be overridden)

### <a name="dovecot--create_config_resources"></a>`dovecot::create_config_resources`

Type: Puppet Language

Create dovecot::config resources from a nested hash, suitable for
conveniently loading values from hiera.
The key-value pairs from the hash represent config keys and values
passed to dovecot::config for simple values, Hash values recursively
create nested sections, and Array values are joined with spaces.

#### `dovecot::create_config_resources(Hash[String, NotUndef] $config_hash, Hash $params = {}, Array[String] $sections = [])`

Create dovecot::config resources from a nested hash, suitable for
conveniently loading values from hiera.
The key-value pairs from the hash represent config keys and values
passed to dovecot::config for simple values, Hash values recursively
create nested sections, and Array values are joined with spaces.

Returns: `Any`

##### `config_hash`

Data type: `Hash[String, NotUndef]`

a hash of (non-hierarchical) key names mapped to values

##### `params`

Data type: `Hash`

a hash of params passed to dovecot::config (must not include :sections, :key, or :value)

##### `sections`

Data type: `Array[String]`

the section names of the hierarchical key, will usually only be specified
on recursive calls from within this function itself

### <a name="dovecot--create_extconfigfile_resources"></a>`dovecot::create_extconfigfile_resources`

Type: Puppet Language

Function: dovecot::create_extconfigfile_resources()
=============

Create {dovecot::extconfigfile} resources from a nested hash, suitable for
conveniently loading values from hiera.

The first level of keys is the config files to be written to, the
values being the hierarchical values that will be passed to the extconfigfile
resource.

Values can either be a Hash[String, String], or a hash containing two properties
`entries` and `additional_content`.

#### `dovecot::create_extconfigfile_resources(Hash[String, Hash] $configfile_hash)`

Function: dovecot::create_extconfigfile_resources()
=============

Create {dovecot::extconfigfile} resources from a nested hash, suitable for
conveniently loading values from hiera.

The first level of keys is the config files to be written to, the
values being the hierarchical values that will be passed to the extconfigfile
resource.

Values can either be a Hash[String, String], or a hash containing two properties
`entries` and `additional_content`.

Returns: `Any`

##### `configfile_hash`

Data type: `Hash[String, Hash]`

a hash of config file names mapped to config hashes

### <a name="dovecot--print_config_value"></a>`dovecot::print_config_value`

Type: Puppet Language

Function: dovecot::print_config_value()
===================

#### `dovecot::print_config_value(Any $value)`

Function: dovecot::print_config_value()
===================

Returns: `Any` the formatted config value suitable for inclusion in a dovecot config file

##### `value`

Data type: `Any`

the value to be printed

